import * as Errors from "./error.js";
import * as Uploads from "./uploads.js";
import { type Agent } from "./_shims/index.js";
import * as Core from "./core.js";
import * as API from "./resources/index.js";
export interface ClientOptions {
    /**
     * Override the default base URL for the API, e.g., "https://api.example.com/v2/"
     *
     * Defaults to process.env['DHAN_SDK_BASE_URL'].
     */
    baseURL?: string | null | undefined;
    /**
     * The maximum amount of time (in milliseconds) that the client should wait for a response
     * from the server before timing out a single request.
     *
     * Note that request timeouts are retried by default, so in a worst-case scenario you may wait
     * much longer than this timeout before the promise succeeds or fails.
     */
    timeout?: number;
    /**
     * An HTTP agent used to manage HTTP(S) connections.
     *
     * If not provided, an agent will be constructed by default in the Node.js environment,
     * otherwise no agent is used.
     */
    httpAgent?: Agent;
    /**
     * Specify a custom `fetch` function implementation.
     *
     * If not provided, we use `node-fetch` on Node.js and otherwise expect that `fetch` is
     * defined globally.
     */
    fetch?: Core.Fetch | undefined;
    /**
     * The maximum number of times that the client will retry a request in case of a
     * temporary failure, like a network error or a 5XX error from the server.
     *
     * @default 2
     */
    maxRetries?: number;
    /**
     * Default headers to include with every request to the API.
     *
     * These can be removed in individual requests by explicitly setting the
     * header to `undefined` or `null` in request options.
     */
    defaultHeaders?: Core.Headers;
    /**
     * Default query parameters to include with every request to the API.
     *
     * These can be removed in individual requests by explicitly setting the
     * param to `undefined` in request options.
     */
    defaultQuery?: Core.DefaultQuery;
}
/**
 * API Client for interfacing with the Dhan SDK API.
 */
export declare class DhanSDK extends Core.APIClient {
    private _options;
    /**
     * API Client for interfacing with the Dhan SDK API.
     *
     * @param {string} [opts.baseURL=process.env['DHAN_SDK_BASE_URL'] ?? https://api.dhan.co/v2] - Override the default base URL for the API.
     * @param {number} [opts.timeout=1 minute] - The maximum amount of time (in milliseconds) the client will wait for a response before timing out.
     * @param {number} [opts.httpAgent] - An HTTP agent used to manage HTTP(s) connections.
     * @param {Core.Fetch} [opts.fetch] - Specify a custom `fetch` function implementation.
     * @param {number} [opts.maxRetries=2] - The maximum number of times the client will retry a request.
     * @param {Core.Headers} opts.defaultHeaders - Default headers to include with every request to the API.
     * @param {Core.DefaultQuery} opts.defaultQuery - Default query parameters to include with every request to the API.
     */
    constructor({ baseURL, ...opts }?: ClientOptions);
    orders: API.Orders;
    trades: API.Trades;
    foreverOrders: API.ForeverOrders;
    positions: API.Positions;
    holdings: API.Holdings;
    edis: API.Edis;
    killswitch: API.KillswitchResource;
    margincalculator: API.Margincalculator;
    funds: API.Funds;
    statements: API.Statements;
    charts: API.Charts;
    protected defaultQuery(): Core.DefaultQuery | undefined;
    protected defaultHeaders(opts: Core.FinalRequestOptions): Core.Headers;
    static DhanSDK: typeof DhanSDK;
    static DEFAULT_TIMEOUT: number;
    static DhanSDKError: typeof Errors.DhanSDKError;
    static APIError: typeof Errors.APIError;
    static APIConnectionError: typeof Errors.APIConnectionError;
    static APIConnectionTimeoutError: typeof Errors.APIConnectionTimeoutError;
    static APIUserAbortError: typeof Errors.APIUserAbortError;
    static NotFoundError: typeof Errors.NotFoundError;
    static ConflictError: typeof Errors.ConflictError;
    static RateLimitError: typeof Errors.RateLimitError;
    static BadRequestError: typeof Errors.BadRequestError;
    static AuthenticationError: typeof Errors.AuthenticationError;
    static InternalServerError: typeof Errors.InternalServerError;
    static PermissionDeniedError: typeof Errors.PermissionDeniedError;
    static UnprocessableEntityError: typeof Errors.UnprocessableEntityError;
    static toFile: typeof Uploads.toFile;
    static fileFromPath: typeof Uploads.fileFromPath;
}
export declare const DhanSDKError: typeof Errors.DhanSDKError, APIError: typeof Errors.APIError, APIConnectionError: typeof Errors.APIConnectionError, APIConnectionTimeoutError: typeof Errors.APIConnectionTimeoutError, APIUserAbortError: typeof Errors.APIUserAbortError, NotFoundError: typeof Errors.NotFoundError, ConflictError: typeof Errors.ConflictError, RateLimitError: typeof Errors.RateLimitError, BadRequestError: typeof Errors.BadRequestError, AuthenticationError: typeof Errors.AuthenticationError, InternalServerError: typeof Errors.InternalServerError, PermissionDeniedError: typeof Errors.PermissionDeniedError, UnprocessableEntityError: typeof Errors.UnprocessableEntityError;
export import toFile = Uploads.toFile;
export import fileFromPath = Uploads.fileFromPath;
export declare namespace DhanSDK {
    export import RequestOptions = Core.RequestOptions;
    export import Orders = API.Orders;
    export import OrderStatus = API.OrderStatus;
    export import OrderListResponse = API.OrderListResponse;
    export import OrderSlicingResponse = API.OrderSlicingResponse;
    export import OrderCreateParams = API.OrderCreateParams;
    export import OrderRetrieveParams = API.OrderRetrieveParams;
    export import OrderUpdateParams = API.OrderUpdateParams;
    export import OrderListParams = API.OrderListParams;
    export import OrderDeleteParams = API.OrderDeleteParams;
    export import OrderSlicingParams = API.OrderSlicingParams;
    export import Trades = API.Trades;
    export import Trade = API.Trade;
    export import TradeRetrieveResponse = API.TradeRetrieveResponse;
    export import TradeListResponse = API.TradeListResponse;
    export import TradeRetrieveParams = API.TradeRetrieveParams;
    export import TradeListParams = API.TradeListParams;
    export import ForeverOrders = API.ForeverOrders;
    export import GttOrder = API.GttOrder;
    export import GttOrderStatus = API.GttOrderStatus;
    export import ForeverOrderListResponse = API.ForeverOrderListResponse;
    export import ForeverOrderCreateParams = API.ForeverOrderCreateParams;
    export import ForeverOrderUpdateParams = API.ForeverOrderUpdateParams;
    export import ForeverOrderListParams = API.ForeverOrderListParams;
    export import ForeverOrderDeleteParams = API.ForeverOrderDeleteParams;
    export import Positions = API.Positions;
    export import Position = API.Position;
    export import PositionListResponse = API.PositionListResponse;
    export import PositionListParams = API.PositionListParams;
    export import PositionConvertParams = API.PositionConvertParams;
    export import Holdings = API.Holdings;
    export import Holding = API.Holding;
    export import HoldingListResponse = API.HoldingListResponse;
    export import HoldingListParams = API.HoldingListParams;
    export import Edis = API.Edis;
    export import EdisForm = API.EdisForm;
    export import EdisQtyStatus = API.EdisQtyStatus;
    export import EdiBulkformParams = API.EdiBulkformParams;
    export import EdiFormParams = API.EdiFormParams;
    export import EdiInquireParams = API.EdiInquireParams;
    export import KillswitchResource = API.KillswitchResource;
    export import Killswitch = API.Killswitch;
    export import KillswitchControlParams = API.KillswitchControlParams;
    export import Margincalculator = API.Margincalculator;
    export import KnowYourMargin = API.KnowYourMargin;
    export import MargincalculatorCalculateParams = API.MargincalculatorCalculateParams;
    export import Funds = API.Funds;
    export import FundLimit = API.FundLimit;
    export import FundLimitParams = API.FundLimitParams;
    export import Statements = API.Statements;
    export import Ledger = API.Ledger;
    export import StatementLedgerParams = API.StatementLedgerParams;
    export import Charts = API.Charts;
    export import Chart = API.Chart;
    export import ChartHistoricalParams = API.ChartHistoricalParams;
    export import ChartIntradayParams = API.ChartIntradayParams;
    export import Order = API.Order;
}
export default DhanSDK;
//# sourceMappingURL=index.d.ts.map