import { APIResource } from "../../resource.js";
import * as Core from "../../core.js";
import * as TradesAPI from "./trades.js";
import * as HistoryAPI from "./history.js";
export declare class Trades extends APIResource {
    history: HistoryAPI.History;
    /**
     * The api allows user to retrieve trade details using an order id. Often during
     * partial trades or Bracket/ Cover Orders, traders get confused in reading trade
     * from tradebook. The response of this API will include all the trades generated
     * for a particular order id.
     */
    retrieve(orderId: string, params: TradeRetrieveParams, options?: Core.RequestOptions): Core.APIPromise<TradeRetrieveResponse>;
    /**
     * The api allows you retrieve an array of all trades executed in a day.
     */
    list(params: TradeListParams, options?: Core.RequestOptions): Core.APIPromise<TradeListResponse>;
}
export interface Trade {
    /**
     * Record create date time
     */
    createTime?: string;
    /**
     * Custom trading symbol
     */
    customSymbol?: string;
    /**
     * User specific identification generated by Dhan
     */
    dhanClientId?: string;
    /**
     * For F&O, expiry date of contract
     */
    drvExpiryDate?: string;
    /**
     * For Options, type CALL or PUT
     */
    drvOptionType?: 'CALL' | 'PUT' | 'NA';
    /**
     * For Options, Strike Price
     */
    drvStrikePrice?: number;
    /**
     * Order specific identification generated by Exchange
     */
    exchangeOrderId?: string;
    /**
     * | **Enums**    | **Exchange** | **Segment**       |
     * | ------------ | ------------ | ----------------- |
     * | NSE_EQ       | NSE          | Equity Cash       |
     * | NSE_FNO      | NSE          | Futures & Options |
     * | NSE_CURRENCY | NSE          | Currency          |
     * | BSE_EQ       | BSE          | Equity Cash       |
     * | BSE_FNO      | BSE          | Futures & Options |
     * | BSE_CURRENCY | BSE          | Currency          |
     * | MCX_COMM     | MCX          | Commodity         |
     */
    exchangeSegment?: 'NSE_EQ' | 'NSE_FNO' | 'NSE_CURRENCY' | 'BSE_EQ' | 'BSE_FNO' | 'BSE_CURRENCY' | 'MCX_COMM';
    /**
     * Time at which order reached at exchange end
     */
    exchangeTime?: string;
    /**
     * Trade specific identification, generated by exchange once order is executed
     */
    exchangeTradeId?: string;
    /**
     * Order specific identification generated by Dhan
     */
    orderId?: string;
    /**
     * | **Enum Values**  | **Description**             |
     * | ---------------- | --------------------------- |
     * | LIMIT            | For Limit Order types       |
     * | MARKET           | For market Order types      |
     * | STOP_LOSS        | For Stop Loss Limit orders  |
     * | STOP_LOSS_MARKET | For Stop Loss Market orders |
     */
    orderType?: 'LIMIT' | 'MARKET' | 'STOP_LOSS' | 'STOP_LOSS_MARKET';
    /**
     * | **Enum Values** | **Description**                                |
     * | --------------- | ---------------------------------------------- |
     * | CNC             | Cash & Carry for equity deliveries             |
     * | INTRADAY        | Intraday for Equity, Futures & Options         |
     * | MARGIN          | Carry Forward in Futures & Options             |
     * | CO              | Cover Order; entry and stop loss               |
     * | BO              | Bracket Order; entry, stop loss & target price |
     * | MTF             | Margin Traded Fund                             |
     *
     * **CO & BO product types will be valid only for Intraday**
     */
    productType?: 'CNC' | 'INTRADAY' | 'MARGIN' | 'MTF' | 'CO' | 'BO';
    /**
     * Exchange standard identification for each scrip
     */
    securityId?: string;
    /**
     * Price at which trade executed
     */
    tradedPrice?: number;
    /**
     * Number of shares traded
     */
    tradedQuantity?: number;
    /**
     * Exchange standard trading symbol
     */
    tradingSymbol?: string;
    /**
     * Signifies the type of transaction wether it's BUY or SELL
     */
    transactionType?: 'BUY' | 'SELL';
    /**
     * Record update date time
     */
    updateTime?: string;
}
export type TradeRetrieveResponse = Array<Trade>;
export type TradeListResponse = Array<Trade>;
export interface TradeRetrieveParams {
    'access-token': string;
}
export interface TradeListParams {
    'access-token': string;
}
export declare namespace Trades {
    export import Trade = TradesAPI.Trade;
    export import TradeRetrieveResponse = TradesAPI.TradeRetrieveResponse;
    export import TradeListResponse = TradesAPI.TradeListResponse;
    export import TradeRetrieveParams = TradesAPI.TradeRetrieveParams;
    export import TradeListParams = TradesAPI.TradeListParams;
    export import History = HistoryAPI.History;
    export import TradeHistory = HistoryAPI.TradeHistory;
    export import HistoryListResponse = HistoryAPI.HistoryListResponse;
    export import HistoryListParams = HistoryAPI.HistoryListParams;
}
//# sourceMappingURL=trades.d.ts.map